using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.Mvc;
using Syncfusion.Presentation;
using CultureAudit.Models;

namespace CultureAudit.Areas.Admin.Controllers
{
    public class PowerPointController : Controller
    {
        CultureAuditEntities db = new CultureAuditEntities();

        // GET: Admin/PowerPoint
        public ActionResult Index()
        {
            return View();
        }

        public PresentationResult ReportPresentation(int SurveyNumber)
        {
            SurveyDefinition survey = new SurveyDefinition();
            string companyName = survey.GetCompany(SurveyNumber);
            // the following variables will be used to display the info in the table
            int sd;
            int d;
            int nand;
            int a;
            int sa;
            int sdpts;
            int dpts;
            int nandpts;
            int apts;
            int sapts;
            int total;
            int totalpts;
            string percentsd;
            string percentd;
            string percentnand;
            string percenta;
            string percentsa;
            double avg;

            int numCompleted = survey.CountParticipants(SurveyNumber, "Y");
            int Section1 = survey.CountParticipants(SurveyNumber, "1");
            int Participants = numCompleted + Section1;

            //Open a powerpoint presentation
            IPresentation presentation = Presentation.Create();

            //Add cover slide
            ISlide Slide0 = presentation.Slides.Add(SlideLayoutType.Blank);
            IShape textShape = Slide0.AddTextBox(100, 75, 756, 800);
            IParagraph paragraph = textShape.TextBody.AddParagraph();

            //Add some text to it.
            ITextPart textPart = paragraph.AddTextPart(companyName);

            //Set the horizontal alignment of paragraph
            paragraph.HorizontalAlignment = HorizontalAlignmentType.Center;

            //Apply font formatting to the above text
            textPart.Font.FontSize = 80;
            textPart.Font.Bold = true;


            //create new slide
            ISlide Slide1 = presentation.Slides.Add(SlideLayoutType.Blank);
            IShape textShape1 = Slide1.AddTextBox(50, 25, 856, 30);
            IParagraph paragraph1 = textShape.TextBody.AddParagraph();
            //GEt the text to put in header
            string Group1Text = survey.GetGroupText(1);

            //Add above text to this slide above the table
            ITextPart textPart1 = paragraph1.AddTextPart(Group1Text);
            paragraph1.HorizontalAlignment = HorizontalAlignmentType.Center;

            //get the data foir the table
            var Group1Data = db.SurveyScoresByGroup(1, SurveyNumber).ToList();
            int numRows = Group1Data.Count();
            int z = 1;

            //Add a table of info
            ITable table1 = Slide1.Shapes.AddTable((numRows+1), 8, 50, 70, 856, 800);
            IRow row = table1.Rows[0];
            row.Height = 30;
            ICell cell = table1[0, 0];
            cell.TextBody.AddParagraph("");
            cell = table1[0, 1];
            cell.TextBody.AddParagraph("Strongly\r\nDisagree");
            cell = table1[0, 2];
            cell.TextBody.AddParagraph("Disagree");
            cell = table1[0, 3];
            cell.TextBody.AddParagraph("Neither Agree\r\nNor Disagree");
            cell = table1[0, 4];
            cell.TextBody.AddParagraph("Agree");
            cell = table1[0, 5];
            cell.TextBody.AddParagraph("Strongly\r\nAgree");
            cell = table1[0, 6];
            cell.TextBody.AddParagraph("Total");
            cell = table1[0, 7];
            cell.TextBody.AddParagraph("Weighted\r\nAverage");
            foreach (var x in Group1Data)
            {
                int y = 0;
                //determine values for each variable
                sd = Convert.ToInt16(x.StronglyDisagree);
                sdpts = sd * 1;
                if (sd > 0)
                {
                    percentsd = string.Format("{0:N2}", (Convert.ToDouble(sd) / Convert.ToDouble(Participants)) * 100);
                }
                else
                {
                    percentsd = "0%";
                }

                d = Convert.ToInt16(x.Disagree);
                dpts = d * 2;
                if (d > 0)
                {
                    percentd = string.Format("{0:N2}", (Convert.ToDouble(d) / Convert.ToDouble(Participants)) * 100);
                }
                else
                {
                    percentd = "0%";
                }

                nand = Convert.ToInt16(x.NAND);
                nandpts = nand * 3;

                if (nand > 0)
                {
                    percentnand = string.Format("{0:N2}", (Convert.ToDouble(nand) / Convert.ToDouble(Participants)) * 100);
                }
                else
                {
                    percentnand = "0%";
                }

                a = Convert.ToInt16(x.Agree);
                apts = a * 4;

                if (a > 0)
                {
                    percenta = string.Format("{0:N2}%", (Convert.ToDouble(a) / Convert.ToDouble(Participants)) * 100);
                }
                else
                {
                    percenta = "0%";
                }

                sa = Convert.ToInt16(x.StronglyAgree);
                sapts = sa * 5;
                if (sa > 0)
                {
                    percentsa = string.Format("{0:N2}%", (Convert.ToDouble(sa) / Convert.ToDouble(Participants)) * 100);
                }
                else
                {
                    percentsa = "0%";
                }
                total = sd + d + nand + a + sa;
                totalpts = sdpts + dpts + nandpts + apts + sapts;
                avg = Convert.ToDouble(totalpts) / Convert.ToDouble(total);


                //display the information in this row
                cell = table1[z, y];
                cell.TextBody.AddParagraph(x.QuestionText.Replace("#Company#", companyName));
                
                y++;  // column increment
                cell = table1[z, y];
                cell.TextBody.AddParagraph(percentsd.ToString()+"\r\n"+sd.ToString());
                y++;
                cell = table1[z, y];
                cell.TextBody.AddParagraph(percentd.ToString() + "\r\n" + d.ToString());
                y++;
                cell = table1[z, y];
                cell.TextBody.AddParagraph(percentnand.ToString() + "\r\n" + nand.ToString());
                y++;
                cell = table1[z, y];
                cell.TextBody.AddParagraph(percenta.ToString() + "\r\n" + a.ToString());
                y++;
                cell = table1[z, y];
                cell.TextBody.AddParagraph(percentsa.ToString() + "\r\n" + sa.ToString());
                y++;
                cell = table1[z, y];
                cell.TextBody.AddParagraph(total.ToString());
                y++;
                cell = table1[z, y];
                cell.TextBody.AddParagraph(avg.ToString("N2"));
                z++;  //row increment
            }


            // for the chart
            AverageAnswerByGroup mod = new AverageAnswerByGroup();
            mod.GroupNumber = 1;
            mod.SurveyNumber = SurveyNumber;
            List<AverageGroupAnswer_Result> Grp1Avg = mod.AverageGroupScores();

            //Add a chart
            //IPresentationChart chart1 = Slide1.Charts.AddChart(100, 50, 700, 500);

            //chart1.ChartTitle = "";

            //Not sure how to do this
            //chart1.ChartData.SetChartData()

            return new PresentationResult(presentation, "Output.pptx", HttpContext.ApplicationInstance.Response);
        }
    }
}